pub struct SerializableFile {
pub blob_impl: BlobImpl,
pub name: String,
pub modified: i64,
}Fields
blob_impl: BlobImplname: Stringmodified: i64Trait Implementations
Sourceimpl BroadcastClone for SerializableFile
impl BroadcastClone for SerializableFile
Sourcetype Id = NamespaceIndex<FileIndex>
type Id = NamespaceIndex<FileIndex>
The ID type that uniquely identify each value.
Sourcefn source(data: &StructuredSerializedData) -> &Option<FxHashMap<Self::Id, Self>>
fn source(data: &StructuredSerializedData) -> &Option<FxHashMap<Self::Id, Self>>
The field from which to clone values.
Sourcefn destination(
data: &mut StructuredSerializedData,
) -> &mut Option<FxHashMap<Self::Id, Self>>
fn destination( data: &mut StructuredSerializedData, ) -> &mut Option<FxHashMap<Self::Id, Self>>
The field into which to place cloned values.
Sourcefn clone_for_broadcast(&self) -> Option<Self>
fn clone_for_broadcast(&self) -> Option<Self>
Clone this value so that it can be reused with a broadcast channel.
Only return None if cloning is impossible.
Sourceimpl Debug for SerializableFile
impl Debug for SerializableFile
Sourceimpl<'de> Deserialize<'de> for SerializableFile
impl<'de> Deserialize<'de> for SerializableFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MallocSizeOf for SerializableFile
impl MallocSizeOf for SerializableFile
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.